Databases
=========

.. currentmodule:: pglift.databases

Module :mod:`pglift.databases` exposes the following API to manipulate
PostgreSQL databases:

.. autofunction:: create
.. autofunction:: apply
.. autofunction:: exists
.. autofunction:: list
.. autofunction:: get
.. autofunction:: drop
.. autofunction:: run
